#!/usr/bin/env python

"""Configures execution of pytest."""

import pytest


def pytest_addoption(parser):
    """pytest add option."""
    parser.addoption(
        "--allow-xclock-termination",
        action="store_true",
        default=False,
        help="Allow blind termination of xclock instances.",
    )


def pytest_collection_modifyitems(config, items):
    """pytest collection modifier."""

    skip_xclock = pytest.mark.skip(
        reason="Execution of xclock tests requires --allow-xclock-termination option."
    )
    for item in items:
        if (
            "mirror" in item.keywords or "xclock" in item.keywords
        ) and not config.getoption("--allow-xclock-termination"):
            item.add_marker(skip_xclock)


def pytest_configure(config):
    """pytest configuration hook."""
    config.addinivalue_line(
        "markers", "xclock: allow blind termination of xclock instances."
    )
