#!/usr/bin/env python

"""Utility classes."""

import logging
import os
import subprocess

from contextlib import contextmanager
from time import sleep


LOGGER = logging.getLogger(__name__)

QUASI_DETERMINISTIC_DELAY = 2


def kill_all_xclock_instances():
    """Terminate ... with extreme prejudice!"""
    LOGGER.debug("Terminating all xclock instances ...")
    subprocess.run(
        args=["killall", "-9", "xclock"]
    )  # pylint: disable=subprocess-run-check
    # Some display managers are not able to keep up with pytest creating and destroying windows. While
    # this is not exactly deterministic, it does seem to help.
    sleep(QUASI_DETERMINISTIC_DELAY)


@contextmanager
def temporary_environment_variable(key: str, value: str):
    """Context manager to globally define the xdg configuration directory."""
    old = os.environ.get(key, None)
    os.environ[key] = value
    yield None
    if old is not None:
        os.environ[key] = old
    else:
        del os.environ[key]
